@@ -1,3 +1,5 @@
+// SPDX-FileCopyrightText: Copyright (C) DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
 
@@ -16,7 +18,7 @@
 #include <dune/common/std/type_traits.hh>
 
 // dune grid includes
-#if HAVE_UG
+#if HAVE_DUNE_UGGRID
 #include <dune/grid/uggrid.hh>
 #endif
 #if HAVE_ALBERTA
@@ -66,12 +68,12 @@ void testReadingAndWritingGrid( const std::string& path, const std::string& grid
   // Read the grid
   std::cout<<"Using "<<gridManagerName<<std::endl;
   GridFactory<GridType> gridFactory;
-  std::vector<int> boundaryIDs;
-  std::vector<int> elementsIDs;
   const std::string inputName(path+gridName+".msh");
   std::cout<<"Reading mesh file "<<inputName<<std::endl;
-  GmshReader<GridType>::read(gridFactory,inputName,boundaryIDs,elementsIDs);
-  auto grid=gridFactory.createGrid();
+  auto reader = GmshReader<GridType>(inputName, gridFactory);
+  auto grid = gridFactory.createGrid();
+  auto elementsIDs = reader.extractElementData();
+  auto boundaryIDs = reader.extractBoundaryData();
 
   // Reorder boundary IDs according to the inserction index
   const auto leafGridView(grid->leafGridView());
