@@ -1,3 +1,5 @@
+// SPDX-FileCopyrightText: Copyright (C) DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
 
@@ -13,7 +15,6 @@
 #include <vector>
 #include <array>
 
-#include <dune/common/std/make_array.hh>
 #include <dune/common/fvector.hh>
 #include <dune/common/parallel/mpihelper.hh>
 
@@ -26,7 +27,7 @@ class VTKVectorFunction
   : public Dune :: VTKWriter< GridView > :: VTKFunction
 {
   // extract types
-  enum { n = GridView :: dimension };
+  constexpr static int n = GridView :: dimension;
   typedef typename GridView :: Grid :: ctype DT;
   typedef typename GridView :: template Codim< 0 > :: Entity Entity;
   const std::string type_;
@@ -89,7 +90,7 @@ int doWrite( Dune::VTKChecker& vtkChecker, const std::string& gridViewName,
              const std::string &refinementName,
              Dune::RefinementIntervals intervals )
 {
-  enum { dim = GridView :: dimension };
+  constexpr static int dim = GridView :: dimension;
 
   Dune :: SubsamplingVTKWriter< GridView > vtk( gridView, intervals, coerceToSimplex);
 
@@ -183,17 +184,16 @@ int main(int argc, char **argv)
                 << std::endl;
 
     int result = 0; // pass by default
-    using Dune::Std::make_array;
 
     Dune::VTKChecker vtkChecker;
 
-    acc(result, vtkCheck<1>(vtkChecker, make_array(5), {1.0}));
-    acc(result, vtkCheck<2>(vtkChecker, make_array(5,5), {1.0, 2.0}));
-    acc(result, vtkCheck<3>(vtkChecker, make_array(5,5,5), {1.0, 2.0, 3.0}));
+    acc(result, vtkCheck<1>(vtkChecker, std::array{5}, {1.0}));
+    acc(result, vtkCheck<2>(vtkChecker, std::array{5, 5}, {1.0, 2.0}));
+    acc(result, vtkCheck<3>(vtkChecker, std::array{5, 5, 5}, {1.0, 2.0, 3.0}));
 
     acc(result, vtkChecker.check());
 
-    mpiHelper.getCollectiveCommunication().allreduce<Acc>(&result, 1);
+    mpiHelper.getCommunication().allreduce<Acc>(&result, 1);
 
     return result;
 
