@@ -1,3 +1,5 @@
+// SPDX-FileCopyrightText: Copyright (C) DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
 
@@ -51,8 +53,8 @@ class VTKVectorFunction
   : public Dune :: VTKWriter< GridView > :: VTKFunction
 {
   // extract types
-  enum { n = GridView :: dimension };
-  enum { w = GridView :: dimensionworld };
+  constexpr static int n = GridView :: dimension;
+  constexpr static int w = GridView :: dimensionworld;
   typedef typename GridView :: Grid :: ctype DT;
   typedef typename GridView :: template Codim< 0 > :: Entity Entity;
   double time_;
@@ -90,7 +92,7 @@ template< class GridView >
 std::string doWrite( const GridView &gridView, Dune::VTK::DataMode dm,
                      bool testRestart = false)
 {
-  enum { dim = GridView :: dimension };
+  constexpr static int dim = GridView :: dimension;
 
   const typename GridView :: IndexSet &is = gridView.indexSet();
   std::vector<int> vertexdata(is.size(dim),dim);
