@@ -1,3 +1,5 @@
+// SPDX-FileCopyrightText: Copyright (C) DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
 
@@ -12,7 +14,6 @@
 #include <string>
 #include <vector>
 
-#include <dune/common/std/make_array.hh>
 #include <dune/common/fvector.hh>
 #include <dune/common/parallel/mpihelper.hh>
 
@@ -37,7 +38,7 @@ class VTKVectorFunction
   : public Dune :: VTKWriter< GridView > :: VTKFunction
 {
   // extract types
-  enum { n = GridView :: dimension };
+  constexpr static int n = GridView :: dimension;
   typedef typename GridView :: Grid :: ctype DT;
   typedef typename GridView :: template Codim< 0 > :: Entity Entity;
   const std::string type_;
@@ -96,7 +97,7 @@ struct Acc
 template< class GridView >
 int doWrite( Dune::VTKChecker& vtkChecker, const std::string& gridViewName, const GridView &gridView, Dune :: VTK :: DataMode dm, const std::string& path = "./" )
 {
-  enum { dim = GridView :: dimension };
+  constexpr static int dim = GridView :: dimension;
 
   Dune :: VTKWriter< GridView > vtk( gridView, dm );
 
@@ -203,17 +204,16 @@ int main(int argc, char **argv)
                 << std::endl;
 
     int result = 0; // pass by default
-    using Dune::Std::make_array;
 
     Dune::VTKChecker vtkChecker;
 
-    acc(result, vtkCheck<1>(vtkChecker, make_array(8), {1.0}));
-    acc(result, vtkCheck<2>(vtkChecker, make_array(8,4), {1.0, 2.0}));
-    acc(result, vtkCheck<3>(vtkChecker, make_array(8,4,4), {1.0, 2.0, 3.0}));
+    acc(result, vtkCheck<1>(vtkChecker, std::array{8}, {1.0}));
+    acc(result, vtkCheck<2>(vtkChecker, std::array{8, 4}, {1.0, 2.0}));
+    acc(result, vtkCheck<3>(vtkChecker, std::array{8, 4, 4}, {1.0, 2.0, 3.0}));
 
     acc(result, vtkChecker.check());
 
-    mpiHelper.getCollectiveCommunication().allreduce<Acc>(&result, 1);
+    mpiHelper.getCommunication().allreduce<Acc>(&result, 1);
 
     return result;
 
