@@ -1,3 +1,5 @@
+// SPDX-FileCopyrightText: Copyright (C) DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception
 /*
  * Test that an implicit copy generator is available for classes derived from
  * - Dune::AnalyticalCoordFunction
@@ -50,13 +52,13 @@ int main()
   {
     Analytical a({1., 2., 3.});
     Analytical b = a;
-    Analytical c(b);
+    [[maybe_unused]] Analytical c(b);
   }
 
   {
     Discrete a({1., 2., 3.});
     Discrete b = a;
-    Discrete c(b);
+    [[maybe_unused]] Discrete c(b);
   }
 
   return 0;
