@@ -1,3 +1,5 @@
+// SPDX-FileCopyrightText: Copyright (C) DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
 #include <config.h>
@@ -60,11 +62,12 @@ int main (int argc, char *argv[])
   DeformationFunction deformation;
   DeformedGridType defGrid(grid,deformation);
 
-  LeafMultipleCodimMultipleGeomTypeMapper<DeformedGridType> mapper(defGrid, mcmgElementLayout());
+  using GV = typename DeformedGridType::LeafGridView;
+  MultipleCodimMultipleGeomTypeMapper<GV> mapper(defGrid.leafGridView(), mcmgElementLayout());
 
   //grid.globalRefine(1);
   //defGrid.update();
 
-  mapper.update();
+  mapper.update(defGrid.leafGridView());
 
 }
