@@ -1,3 +1,5 @@
+// SPDX-FileCopyrightText: Copyright (C) DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
 // Test parallel interface if a parallel UG is used
@@ -13,6 +15,7 @@
 
 #include <dune/common/parallel/mpihelper.hh>
 #include <dune/common/float_cmp.hh>
+#include <dune/common/stdstreams.hh>
 #include <dune/geometry/referenceelements.hh>
 #include <dune/grid/common/gridenums.hh>
 #include <dune/grid/common/mcmgmapper.hh>
@@ -79,7 +82,7 @@ public:
 
     userDataSend_[mapper_.index(e)][0] = x;
     dverb << "Process "
-              << Dune::MPIHelper::getCollectiveCommunication().rank()+1
+              << Dune::MPIHelper::getCommunication().rank()+1
               << " sends for entity "
               << mapper_.index(e)
               << ": "
@@ -102,7 +105,7 @@ public:
     userDataReceive_[mapper_.index(e)][0] = x;
     scatterCounter_[mapper_.index(e)]++;
     dverb << "Process "
-              << Dune::MPIHelper::getCollectiveCommunication().rank()+1
+              << Dune::MPIHelper::getCommunication().rank()+1
               << " received for entity "
               << mapper_.index(e)
               << ": "
