@@ -1,3 +1,5 @@
+// SPDX-FileCopyrightText: Copyright (C) DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
 
@@ -179,7 +181,7 @@ int main(int argc , char **argv) {
     // Initialize MPI, if present
 
     Dune::MPIHelper::instance(argc, argv);
-    check_yasp_3d(rank0Stream(std::cout,Dune::MPIHelper::getCollectiveCommunication()));
+    check_yasp_3d(rank0Stream(std::cout,Dune::MPIHelper::getCommunication()));
 
   } catch (Dune::Exception &e) {
     std::cerr << e << std::endl;
