@@ -1,7 +1,10 @@
+// SPDX-FileCopyrightText: Copyright (C) DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception
 #include "config.h"
 
 #include <iostream>
 
+#include <dune/common/deprecated.hh>
 #include <dune/common/test/testsuite.hh>
 #include <dune/grid/yaspgrid.hh>
 
@@ -25,7 +28,9 @@ TestSuite testBinomialTable(std::vector<int> const* reference = nullptr, bool du
     for (int c = 0; c <= d; ++c, ++i) {
       const auto value = Table::evaluate(d, c);
 
+      DUNE_NO_DEPRECATED_BEGIN
       t.check(value == Table::binomial(d, c));
+      DUNE_NO_DEPRECATED_END
       if (reference)
         t.check(Table::evaluate(d, c) == reference->at(i));
 
