@@ -1,3 +1,5 @@
+// SPDX-FileCopyrightText: Copyright (C) DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
 
@@ -33,7 +35,7 @@ template<> int UGGrid<3>::numOfUGGrids = 0;
 
 
 template <int dim>
-UGGrid < dim >::UGGrid(UGCollectiveCommunication comm)
+UGGrid < dim >::UGGrid(UGCommunication comm)
   : multigrid_(nullptr),
     ccobj_(comm),
     leafIndexSet_(*this),
