@@ -1,3 +1,5 @@
+// SPDX-FileCopyrightText: Copyright (C) DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
 
@@ -201,10 +203,12 @@ insertBoundarySegment(const std::vector<unsigned int>& vertices,
   for (size_t i=vertices.size(); i<dimworld*2-2; i++)
     segmentVertices[i] = -1;
 
-  // DUNE --> UG vertex renumbering for quadrilateral boundary segments
-  if (vertices.size()==4) {
-    segmentVertices[2] = vertices[3];
-    segmentVertices[3] = vertices[2];
+  // DUNE --> UG vertex renumbering for quadrilateral boundary segments (3D only)
+  if constexpr (dimworld == 3) {
+    if (vertices.size()==4) {
+      segmentVertices[2] = vertices[3];
+      segmentVertices[3] = vertices[2];
+    }
   }
 
   boundarySegmentVertices_.push_back(segmentVertices);
