@@ -1,3 +1,5 @@
+// SPDX-FileCopyrightText: Copyright (C) DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
 #include "config.h"
@@ -64,25 +66,25 @@ void checkIndexSet(const GridView& gridView,
 
   if (gridView.comm().rank()==0)
     for (size_t i=0; i<indicesGlobal.size(); i++)
-      if ( indicesGlobal[i] != i )
+      if ( (size_t) indicesGlobal[i] != i )
         DUNE_THROW(Exception, i << "th global index is not " << i);
 
 }
 
 int main(int argc, char* argv[]) try
 {
-#if HAVE_UG
+#if HAVE_DUNE_UGGRID
   Dune::MPIHelper& mpiHelper =
-#endif // #if HAVE_UG
+#endif
   MPIHelper::instance(argc, argv);
 
   ////////////////////////////////////////////////////
   //  Create a distributed YaspGrid
   ////////////////////////////////////////////////////
 
-#if HAVE_UG
+#if HAVE_DUNE_UGGRID
   static const int dim = 2;
-#endif // #if HAVE_UG
+#endif
   // Disable the YaspGrid test for the time being.  It crashes in many situations
   // and I suspect that that's caused by bugs in YaspGrid.  I'll need to investigate that.
 #if 0
@@ -99,7 +101,7 @@ int main(int argc, char* argv[]) try
   GridView gridView = grid.leafGridView();
 #endif
 
-#if HAVE_UG
+#if HAVE_DUNE_UGGRID
   typedef UGGrid<dim> GridType;
 
   std::array<unsigned int,dim> elements = { {8, 8} };
