@@ -1,3 +1,5 @@
+// SPDX-FileCopyrightText: Copyright (C) DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
 
@@ -302,12 +304,12 @@ try {
 
   std::cout << "= Testing 2D" << std::endl;
 
-#if HAVE_UG
+#if HAVE_DUNE_UGGRID
   std::cout << "== Testing UGGrid<2> with simplices" << std::endl;
   testVertexOrderByIdCubes<Dune::UGGrid<2> >(result);
   std::cout << "== Testing UGGrid<2> with cubes" << std::endl;
   testVertexOrderByIdSimplices<Dune::UGGrid<2> >(result);
-#endif // HAVE_UG
+#endif
 
   //////////////////////////////////////////////////////////////////////
   //   Test 3d grids
@@ -315,12 +317,12 @@ try {
 
   std::cout << "= Testing 3D" << std::endl;
 
-#if HAVE_UG
+#if HAVE_DUNE_UGGRID
   std::cout << "== Testing UGGrid<3> with simplices" << std::endl;
   testVertexOrderByIdCubes<Dune::UGGrid<3> >(result);
   std::cout << "== Testing UGGrid<3> with cubes" << std::endl;
   testVertexOrderByIdSimplices<Dune::UGGrid<3> >(result);
-#endif // HAVE_UG
+#endif
 
   return result;
 }
