@@ -1,7 +1,10 @@
+# SPDX-FileCopyrightText: Copyright (C) DUNE Project contributors, see file LICENSE.md in module root
+# SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception
+
 import os
 
 path = os.path.join( os.path.dirname(__file__), "tutorial" )
-execute  = "cp -r " + path + " "
+execute  = "cp -RL " + path + " "
 execute += "grid_tutorial"
 status = os.system(execute)
 if status != 0: raise RuntimeError(status)
