@@ -1,3 +1,6 @@
+# SPDX-FileCopyrightText: Copyright (C) DUNE Project contributors, see file LICENSE.md in module root
+# SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception
+
 from dune.generator.generator import SimpleGenerator
 
 from dune.common.hashit import hashIt
@@ -10,6 +13,6 @@ def load(includes, typeName, *args):
     return generator.load(includes, typeName, moduleName, *args)
 
 def dataHandle(mapper,array,function):
-    typeName = "Dune::Python::NumPyCommDataHandle< " + mapper._typeName + ", double, std::function<double(double,double)> >"
-    includes = mapper._includes
+    typeName = "Dune::Python::NumPyCommDataHandle< " + mapper.cppTypeName + ", double, std::function<double(double,double)> >"
+    includes = mapper.cppIncludes
     return load(includes, typeName).DataHandle(mapper,array,function)
